@@ -1,9 +1,7 @@
-package URI::Fetch::Response;
-$URI::Fetch::Response::VERSION = '0.13_01'; # TRIAL
+# $Id: Response.pm 1930 2006-04-10 01:54:28Z btrott $
 
-$URI::Fetch::Response::VERSION = '0.1301';
+package URI::Fetch::Response;
 use strict;
-use warnings;
 
 sub new {
     my $class = shift;
@@ -27,27 +25,9 @@ sub uri           { shift->_var('uri',           @_) }
 sub content       { shift->_var('content',       @_) }
 sub content_type  { shift->_var('content_type',  @_) }
 
-sub is_success  {
-    my $response = shift;
-    if ($response->http_response) {
-        return 1 if $response->http_response->code == 304
-                 && defined($response->content);
-        return $response->http_response->is_success;
-    }
-    return 1;
-}
-
-sub is_redirect {
-    my $response = shift;
-    return $response->http_response->is_redirect if $response->http_response;
-    return;
-}
-
-sub is_error    {
-    my $response = shift;
-    return $response->http_response->is_error if $response->http_response;
-    return;
-}
+sub is_success  { $_[0]->http_response->is_success  }
+sub is_redirect { $_[0]->http_response->is_redirect }
+sub is_error    { $_[0]->http_response->is_error    }
 
 1;
 __END__
@@ -122,11 +102,6 @@ The I<HTTP::Response> object returned from the fetch.
 Wrappers around the C<$res-E<gt>response> methods of the same name, for
 convenience.
 
-B<Note:> there is one difference from the behaviour of L<HTTP::Response>.
-If you are using a cache and get a 304 response, but the data is retrieved
-from the cache, then C<is_success> will return true,
-because C<res-E<gt>content> is usable.
-
 =head2 $res->content_type
 
 The Content-Type header from the response.
